@@ -8,12 +8,14 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import Union, Any, Optional
+
 from pip_services3_commons.convert.LongConverter import LongConverter
 
 
-class IntegerConverter():
+class IntegerConverter:
     """
-    Converts arbitrary values into integers using extended conversion rules:
+    Converts arbitrary values into integers using extended conversion __rules:
     - Strings are converted to floats, then to integers
     - DateTime: total number of milliseconds since unix epoсh
     - Boolean: 1 for true and 0 for false
@@ -29,36 +31,36 @@ class IntegerConverter():
     """
 
     @staticmethod
-    def to_nullable_integer(value):
+    def to_nullable_integer(value: Any) -> Optional[int]:
         """
-        Converts value into integer or returns null when conversion is not possible.
+        Converts args into integer or returns null when conversion is not possible.
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
-        :return: integer value or null when conversion is not supported.
+        :return: integer args or null when conversion is not supported.
         """
         return LongConverter.to_nullable_long(value)
 
     @staticmethod
-    def to_integer(value):
+    def to_integer(value: Any) -> int:
         """
-        Converts value into integer or returns 0 when conversion is not possible.
+        Converts args into integer or returns 0 when conversion is not possible.
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
-        :return: integer value or 0 when conversion is not supported.
+        :return: integer args or 0 when conversion is not supported.
         """
         return LongConverter.to_long(value)
 
     @staticmethod
-    def to_integer_with_default(value, default_value):
+    def to_integer_with_default(value: Any, default_value: int) -> int:
         """
-        Converts value into integer or returns default value when conversion is not possible.
+        Converts args into integer or returns default args when conversion is not possible.
 
-        :param value: the value to convert.
+        :param value: the args to convert.
 
-        :param default_value: the default value.
+        :param default_value: the default args.
 
-        :return: integer value or default when conversion is not supported.
+        :return: integer args or default when conversion is not supported.
         """
         return LongConverter.to_long_with_default(value, default_value)
