@@ -9,7 +9,7 @@
     :license: MIT, see LICENSE for more details.
 """
 
-class TypeCode():
+class TypeCode:
     """
     Codes for the data types that can be converted using :class:`TypeConverter <pip_services3_commons.convert.TypeConverter.TypeConverter>`.
     """
