@@ -3,14 +3,16 @@
     pip_services_common.errors.UnauthorizedException
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
     
-    Unauthorized exception type
+    Unauthorized error type
     
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import Optional
 
-from .ErrorCategory import ErrorCategory
 from .ApplicationException import ApplicationException
+from .ErrorCategory import ErrorCategory
+
 
 class UnauthorizedException(ApplicationException):
     """
@@ -18,7 +20,7 @@ class UnauthorizedException(ApplicationException):
     or incorrect security permissions (authorization error).
     """
 
-    def __init__(self, correlation_id = None, code = None, message = None):
+    def __init__(self, correlation_id: Optional[str] = None, code: str = None, message: str = None):
         """
         Creates an error instance and assigns its values.
 
