@@ -8,7 +8,9 @@
     :copyright: Conceptual Vision Consulting LLC 2018-2019, see AUTHORS for more details.
     :license: MIT, see LICENSE for more details.
 """
+from typing import Any, List
 
+from pip_services3_commons.validate import IValidationRule
 from .Schema import Schema
 from .ValidationResult import ValidationResult
 from .ValidationResultType import ValidationResultType
@@ -28,33 +30,70 @@ class MapSchema(Schema):
         schema.validate({ "key1": 1, "key2": 2 })           # Result: element type mismatch
         schema.validate([ 1, 2, 3 ])                        # Result: type mismatch
     """
-    key_type = None
-    value_type = None
+    __key_type: Any = None
+    __value_type: Any = None
 
-    def __init__(self, key_type=None, value_type=None, required=None, rules=None):
+    def __init__(self, key_type: Any = None, value_type: Any = None, required: bool = None,
+                 rules: List[IValidationRule] = None):
         """
         Creates a new instance of validation schema and sets its values.
 
         :param key_type: a type of map keys. Null means that keys may have any type.
         :param value_type: a type of map values. Null means that values may have any type.
         :param required: (optional) true to always require non-null values.
-        :param rules: (optional) a list with validation rules.
+        :param rules: (optional) a list with validation __rules.
         """
         super(MapSchema, self).__init__(required, rules)
-        self.key_type = key_type
-        self.value_type = value_type
+        self.__key_type = key_type
+        self.__value_type = value_type
 
-    def _perform_validation(self, path, value, results):
+    def get_key_type(self) -> Any:
         """
-        Validates a given value against the schema and configured validation rules.
+        Gets the type of map keys.
+        None means that keys may have any type.
 
-        :param path: a dot notation path to the value.
+        :returns: the type of map keys.
+        """
+        return self.__key_type
 
-        :param value: a value to be validated.
+    def set_key_type(self, value: Any):
+        """
+        Sets the type of map keys.
+        None means that keys may have any type.
+
+        :param value: a type of map keys.
+        """
+        self.__key_type = value
+
+    def get_value_type(self) -> Any:
+        """
+        Gets the type of map values.
+        None means that values may have any type.
+
+        :return: the type of map values.
+        """
+        return self.__value_type
+
+    def set_value_type(self, value: Any):
+        """
+        Sets the type of map values.
+        Null means that values may have any type.
+
+        :return: a type of map values.
+        """
+        self.__value_type = value
+
+    def _perform_validation(self, path: str, value: Any, results: List[ValidationResult]):
+        """
+        Validates a given args against the schema and configured validation __rules.
+
+        :param path: a dot notation path to the args.
+
+        :param value: a args to be validated.
 
         :param results: a list with validation results to add new results.
         """
-        name = path if not (path is None) else "value"
+        name = path if not (path is None) else "args"
         value = ObjectReader.get_value(value)
 
         super(MapSchema, self)._perform_validation(path, value, results)
@@ -66,8 +105,8 @@ class MapSchema(Schema):
             for (key, value) in value.items():
                 element_path = key if path is None or len(path) == 0 else path + "." + key
 
-                self._perform_type_validation(element_path, self.key_type, key, results)
-                self._perform_type_validation(element_path, self.value_type, value, results)
+                self._perform_type_validation(element_path, self.__key_type, key, results)
+                self._perform_type_validation(element_path, self.__value_type, value, results)
         else:
             results.append(
                 ValidationResult(
